@@ -390,7 +390,7 @@ def measurable_elemwise_logprob(
 def measurable_true_divide(fgraph, node):
     r"""Rewrite a `true_divide` node to a `MeasurableVariable`.
 
-    TODO FIXME: We need update/clarify the canonicalization situation so that
+    TODO FIXME: We need to update/clarify the canonicalization situation so that
     these can be reliably rewritten as products of reciprocals.
 
     """
@@ -400,7 +400,7 @@ def measurable_true_divide(fgraph, node):
     # `denominator` is measurable
     res = measurable_reciprocal.transform(fgraph, reciprocal_denominator.owner)
     if res:
-        return measurable_mul.transform(fgraph, at.mul(numerator, res[0]).owner)
+        reciprocal_denominator = res[0]
 
     # `numerator` is measurable
     return measurable_mul.transform(
@@ -413,8 +413,8 @@ def measurable_true_divide(fgraph, node):
 def measurable_sub(fgraph, node):
     r"""Rewrite a `sub` node to a `MeasurableVariable`.
 
-    TODO FIXME: We need update/clarify the canonicalization situation so that
-    these can be reliably rewritten as products of reciprocals.
+    TODO FIXME: We need to update/clarify the canonicalization situation so
+    that these can be reliably rewritten.
 
     """
     minuend, subtrahend = node.inputs
@@ -424,7 +424,7 @@ def measurable_sub(fgraph, node):
     # `subtrahend` is measurable
     res = measurable_mul.transform(fgraph, mul_subtrahend.owner)
     if res:
-        return measurable_add.transform(fgraph, at.add(minuend, res[0]).owner)
+        mul_subtrahend = res[0]
 
     # TODO FIXME: `local_add_canonizer` will unreliably rewrite expressions like
     # `x - y` to `-y + x` (e.g. apparently when `y` is a constant?) and, as a result,
@@ -537,7 +537,7 @@ def construct_elemwise_transform(
         for idx, inp in enumerate(node.inputs)
         if inp.owner
         and isinstance(inp.owner.op, MeasurableVariable)
-        and not isinstance(inp, ValuedVariable)
+        and not isinstance(inp.owner.op, ValuedVariable)
     ]
 
     if len(measurable_inputs) != 1:
@@ -562,19 +562,19 @@ def construct_elemwise_transform(
         if (
             var.owner
             and not isinstance(var.owner.op, MeasurableVariable)
-            and not isinstance(var, ValuedVariable)
+            and not isinstance(var.owner.op, ValuedVariable)
         ):
             new_vars.extend(reversed(var.owner.inputs))
 
         return new_vars
 
     if any(
-        ancestor_node
-        for ancestor_node in walk(other_inputs, expand, False)
+        var
+        for var in walk(other_inputs, expand, False)
         if (
-            ancestor_node.owner
-            and isinstance(ancestor_node.owner.op, MeasurableVariable)
-            and not isinstance(ancestor_node, ValuedVariable)
+            var.owner
+            and isinstance(var.owner.op, MeasurableVariable)
+            and not isinstance(var.owner.op, ValuedVariable)
         )
     ):
         return None
